package com.ruoyi.rocketmq.mapper;

import com.ruoyi.rocketmq.domain.InitialDiskInfo;
import org.springframework.data.repository.query.Param;

import java.util.List;
import java.util.Map;

/**
 * 磁盘监控信息Mapper接口
 * 
 * @author gyt
 * @date 2025-08-25
 */
public interface InitialDiskInfoMapper 
{
    /**
     * 查询磁盘监控信息
     * 
     * @param id 磁盘监控信息主键
     * @return 磁盘监控信息
     */
    public InitialDiskInfo selectInitialDiskInfoById(Long id);

    /**
     * 查询磁盘监控信息列表
     * 
     * @param initialDiskInfo 磁盘监控信息
     * @return 磁盘监控信息集合
     */
    public List<InitialDiskInfo> selectInitialDiskInfoList(InitialDiskInfo initialDiskInfo);

    /**
     * 新增磁盘监控信息
     * 
     * @param initialDiskInfo 磁盘监控信息
     * @return 结果
     */
    public int insertInitialDiskInfo(InitialDiskInfo initialDiskInfo);

    /**
     * 修改磁盘监控信息
     * 
     * @param initialDiskInfo 磁盘监控信息
     * @return 结果
     */
    public int updateInitialDiskInfo(InitialDiskInfo initialDiskInfo);

    /**
     * 删除磁盘监控信息
     * 
     * @param id 磁盘监控信息主键
     * @return 结果
     */
    public int deleteInitialDiskInfoById(Long id);

    /**
     * 批量删除磁盘监控信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInitialDiskInfoByIds(Long[] ids);

    /**
     * 批量新增磁盘监控信息
     *
     * @param list 磁盘监控信息集合
     * @return 结果
     */
    public int batchInsertInitialDiskInfo(@Param("list") List<InitialDiskInfo> list);

    /**
     * 获取磁盘设备基础信息
     * @param initialDiskInfo
     * @return
     */
    InitialDiskInfo getDistDetailsMsgByClientId(InitialDiskInfo initialDiskInfo);

    /**
     * 获取指定服务器的磁盘名称
     * @param initialDiskInfo
     * @return
     */
    List<Map> getAllDistName(InitialDiskInfo initialDiskInfo);
}
